startLocationUpdating method
Starts receiving the user’s current location.
use this method to start only receiving the user location without controlling the map which you can do that manually
Implementation
Future<void> startLocationUpdating({
bool enableStopFollow = false,
bool disableUserMarkerRotation = false,
Anchor anchor = Anchor.center,
bool useDirectionMarker = false,
}) async {
final status = await PermissionManager.request(
PermissionManagerPermission.location,
);
if (status == PermissionManagerStatus.granted ||
status == PermissionManagerStatus.limited) {
// Permission granted
await osmBaseController.startLocationUpdating();
} else if (status == PermissionManagerStatus.permanentlyDenied) {
return;
}
}